;-------------------------------------------------------------------------------------
; Ilya Mamontov
; Project to demonstrate a non-standard PRS operating (as one-short and debouncer)
;-------------------------------------------------------------------------------------
; Schematic: LED1 - to P0[6] (Output 1)
;            LED2 - to P0[4] (Output 2)
;            LED3 - to P0[5] (Control of Input)
; P0[5] is Pulses Input

; Output test sequences (rate 8 Hz):
; P2[7] - 1000000000000000 1000000000000000 ...
; P2[5] - 1111111100000000 1111111100000000 ...
; P2[3] - 1011010000000000 1011010000000000 ...
; P2[1] - 1010111111110000 1010111111110000 ...
;-------------------------------------------------------------------------------------
include "m8c.inc"       ; part specific constants and macros
include "PSoCAPI.inc"   ; PSoC API definitions for all User Modules
export _main
_main:
;-------------- Configure and start the PRS8_1 ------------------
	;set the data input
	M8C_SetBank1
	and reg[PRS8_1_INPUT_REG],0x0F	;prepare (clear) 7..4 bits
	or  reg[PRS8_1_INPUT_REG],0xF0	;connect to Row_0_Input_3
	or  reg[PRS8_1_FUNC_REG], 0x80	;the data input should be inverted (for normal operating)
	M8C_SetBank0
	;set the Polynomial, Shift and Seed registers
	mov reg[PRS8_1_POLY_REG],0b00000000	;load the Polynomial register
	mov reg[PRS8_1_SEED_REG],0b00000000	;load the Shift (via Seed) and Seed registers
	lcall   PRS8_1_Start				;start the PRS
 
;-------------- Configure and start the PRS8_2 ------------------
	;set the data input
	M8C_SetBank1
	and reg[PRS8_2_INPUT_REG],0x0F	;prepare (clear) 7..4 bits
	or  reg[PRS8_2_INPUT_REG],0xF0	;connect to Row_0_Input_3
	or  reg[PRS8_2_FUNC_REG], 0x80	;the data input should be inverted (for normal operating)
	M8C_SetBank0
	;set the Polynomial, Shift and Seed registers
	mov reg[PRS8_2_POLY_REG],0b00000000	;load the Polynomial registers
	mov reg[PRS8_2_SEED_REG],0b00000000	;load the Shift (via Seed) register to prevent the single pulse
	lcall   PRS8_2_Start				;start the PRS
	mov reg[PRS8_2_SEED_REG],0b11111111	;load the Seed register

;-------------- Start the Counter16_1 ------------------
    lcall Counter16_1_Start
    lcall Counter16_1_EnableInt

	;load the address of data to pointer (to start pulses generating)
	mov [pt+0],(<data1) ;lsb
	mov [pt+1],(>data1) ;msb

    M8C_EnableGInt ;enable interrupts
    ret
    
.LITERAL    
data1:: ;data array for pulses sequences
;bit 7 5 3 1 
DB 0b10101010	;0
DB 0b00100000	;1
DB 0b00101010	;2
DB 0b00101000	;3
DB 0b00100010	;4
DB 0b00101010	;5
DB 0b00100010	;6
DB 0b00100010	;7
DB 0b00000010	;8
DB 0b00000010	;9
DB 0b00000010	;10
DB 0b00000010	;11
DB 0b00000000	;12
DB 0b00000000	;13
DB 0b00000000	;14
DB 0b00000000	;15
DB 0xFF			;flag of end
.ENDLITERAL